@@ -5,6 +5,7 @@ use clap::Parser;
 use derive_builder::Builder;
 
 use crate::item::RankCriteria;
+use crate::model::options::InfoDisplay;
 use crate::prelude::SkimItemReader;
 use crate::reader::CommandCollector;
 use crate::util::read_file_lines;
@@ -122,13 +123,20 @@ pub struct SkimOptions {
     ///     2..    From the 2nd field to the last field
     ///     ..-3   From the 1st field to the 3rd to the last field
     ///     ..     All the fields
-    #[arg(short, long, default_value = "", help_heading = "Search", verbatim_doc_comment)]
+    #[arg(
+        short,
+        long,
+        default_value = "",
+        help_heading = "Search",
+        verbatim_doc_comment,
+        value_delimiter = ','
+    )]
     pub nth: Vec<String>,
 
     /// Fields to be transformed
     ///
     /// See **nth** for the details
-    #[arg(long, default_value = "", help_heading = "Search")]
+    #[arg(long, default_value = "", help_heading = "Search", value_delimiter = ',')]
     pub with_nth: Vec<String>,
 
     /// Delimiter between fields
@@ -215,7 +223,7 @@ pub struct SkimOptions {
     ///
     ///   ACTION:               DEFAULT BINDINGS (NOTES):
     ///     abort                 ctrl-c  ctrl-q  esc
-    ///     accept                enter
+    ///     accept(...)           enter (the argument will be printed when the binding is triggered)
     ///     append-and-select
     ///     backward-char         ctrl-b  left
     ///     backward-delete-char  ctrl-h  bspace
@@ -302,7 +310,7 @@ pub struct SkimOptions {
     ///
     /// If  the query is empty, skim will execute abort action, otherwise execute delete-char action. It
     /// is equal to ‘delete-char/eof‘.
-    #[arg(short, long, help_heading = "Interface", verbatim_doc_comment)]
+    #[arg(short, long, help_heading = "Interface", verbatim_doc_comment, value_delimiter = ',')]
     pub bind: Vec<String>,
 
     /// Enable multiple selection
@@ -452,7 +460,19 @@ pub struct SkimOptions {
     #[arg(long, default_value = "8", help_heading = "Display")]
     pub tabstop: usize,
 
-    /// Display info next to the query
+    /// Set matching result count display position
+    ///
+    ///     hidden: do not display info
+    ///     inline: display info in the same row as the input
+    ///     default: display info in a dedicated row above the input
+    #[arg(long, help_heading = "Display", value_enum, default_value = "default")]
+    pub info: InfoDisplay,
+
+    /// Alias for --info=hidden
+    #[arg(long, help_heading = "Display")]
+    pub no_info: bool,
+
+    /// Alias for --info=inline
     #[arg(long, help_heading = "Display")]
     pub inline_info: bool,
 
@@ -576,7 +596,7 @@ pub struct SkimOptions {
     /// list.
     ///
     /// e.g. sk --expect=ctrl-v,ctrl-t,alt-s --expect=f1,f2,~,@
-    #[arg(long, help_heading = "Scripting")]
+    #[arg(long, help_heading = "Scripting", value_delimiter = ',')]
     pub expect: Vec<String>,
 
     /// Read input delimited by ASCII NUL(\\0) characters
@@ -641,8 +661,6 @@ pub struct SkimOptions {
     #[arg(long, short, help_heading = "Scripting")]
     pub filter: Option<String>,
 
-    /// Reserved for later use
-    ///
     /// Run in a tmux popup
     ///
     /// Format: sk --tmux <center|top|bottom|left|right>[,SIZE[%]][,SIZE[%]]
@@ -693,10 +711,6 @@ pub struct SkimOptions {
     #[arg(long, hide = true, help_heading = "Reserved for later use")]
     pub no_bold: bool,
 
-    /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
-    pub info: bool,
-
     /// Reserved for later use
     #[arg(long, hide = true, help_heading = "Reserved for later use")]
     pub pointer: bool,
